==> 0.0.2.tar.gz: android/src/main/kotlin/com/example/cs_ironsource_ad/CsIronsourceAdPlugin.kt <==
package com.example.cs_ironsource_ad

import android.app.Activity
import android.util.Log
import androidx.annotation.NonNull
import com.ironsource.mediationsdk.IronSource
import com.ironsource.mediationsdk.logger.IronSourceError
import com.ironsource.mediationsdk.model.Placement
import com.ironsource.mediationsdk.sdk.InterstitialListener
import com.ironsource.mediationsdk.sdk.OfferwallListener
import com.ironsource.mediationsdk.sdk.RewardedVideoListener

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result


/** CsIronsourceAdPlugin */
class CsIronsourceAdPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  var activity: Activity? = null

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "cs_ironsource_android")
    channel.setMethodCallHandler(this)
  }

  fun OnMethodCallHandler(method: String?, vararg args: String) {
    try {
      activity?.runOnUiThread(Runnable { channel.invokeMethod(method!!, args) })
    } catch (e: Exception) {
      Log.e("flutter_ironsource", "Error $e")
    }
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "init") {
      val appKey = call.argument<String>("appKey") ?: ""
      IronSource.init(activity, appKey)
      IronSource.setOfferwallListener(object : OfferwallListener {
        //积分墙是否准备好
        override fun onOfferwallAvailable(isAvailable: Boolean) {
          val arg = if (isAvailable)  "1" else "0"
          OnMethodCallHandler("offerwallAvailable",  isAvailable.toString())
        }

        //加载成功
        override fun onOfferwallOpened() {
          OnMethodCallHandler("offerwallOpened")
        }

        //积分墙展示错误
        override fun onOfferwallShowFailed(error: IronSourceError) {
          OnMethodCallHandler("offerwallShowFailed", error.errorCode.toString())
        }

        //获取奖励
        override fun onOfferwallAdCredited(credits: Int, totalCredits: Int, totalCreditsFlag: Boolean): Boolean {
          val flag = if (totalCreditsFlag) 1 else 0;
          OnMethodCallHandler("offerwallAdCredited", credits.toString(), totalCredits.toString(), flag.toString())
            return true
        }

        //获取积分失败
        override fun onGetOfferwallCreditsFailed(error: IronSourceError) {
          OnMethodCallHandler("getOfferwallCreditsFailed", error.errorCode.toString())
        }

        //关闭积分墙
        override fun onOfferwallClosed() {
          OnMethodCallHandler("offerwallClosed")
        }
      })

      IronSource.setRewardedVideoListener(object : RewardedVideoListener {
        override fun onRewardedVideoAdOpened(){
          OnMethodCallHandler("rewardedVideoAdOpened")
        }

        override fun onRewardedVideoAdClosed(){
          OnMethodCallHandler("rewardedVideoAdClosed")
        }

        override fun onRewardedVideoAvailabilityChanged(isAvailability: Boolean){
          OnMethodCallHandler("rewardedVideoAvailabilityChanged", isAvailability.toString())
        }

        override fun onRewardedVideoAdStarted(){
          OnMethodCallHandler("rewardedVideoAdStarted")
        }

        override fun onRewardedVideoAdEnded(){
          OnMethodCallHandler("rewardedVideoAdEnded")
        }

        override fun onRewardedVideoAdRewarded(placement: Placement?){
          val rewardName = placement?.rewardName.toString()
          val rewardAmount = placement?.rewardAmount.toString()
          OnMethodCallHandler("rewardedVideoAdRewarded", rewardName, rewardAmount)
        }

        override fun onRewardedVideoAdShowFailed(error: IronSourceError?){
          OnMethodCallHandler("rewardedVideoAdShowFailed", error?.errorCode.toString())
        }

        override fun onRewardedVideoAdClicked(placement: Placement?){
          val rewardName = placement?.rewardName.toString()
          val rewardAmount = placement?.rewardAmount.toString()
          OnMethodCallHandler("rewardedVideoAdClicked", rewardName, rewardAmount)
        }
      })

      IronSource.setInterstitialListener(object :InterstitialListener {
        override fun onInterstitialAdReady(){
          OnMethodCallHandler("interstitialAdReady")
        }

        override fun onInterstitialAdLoadFailed(error: IronSourceError?){
          OnMethodCallHandler("interstitialAdLoadFailed")
        }

        override fun onInterstitialAdOpened(){
          OnMethodCallHandler("interstitialAdOpened")
        }

        override fun onInterstitialAdClosed(){
          OnMethodCallHandler("interstitialAdClosed")
        }

        override fun onInterstitialAdShowSucceeded(){
          OnMethodCallHandler("interstitialAdShowSucceeded")
        }

        override fun onInterstitialAdShowFailed(error: IronSourceError?){
          OnMethodCallHandler("interstitialAdShowFailed")
        }

        override fun onInterstitialAdClicked(){
          OnMethodCallHandler("interstitialAdClicked")
        }
      })
    }  else if (call.method == "setUserId") {
      val userId: String = call.argument<String>("userId") ?: return;
      IronSource.setUserId(userId)
    } else if (call.method == "getOfferwallCredits") {
      IronSource.getOfferwallCredits()
    } else if (call.method == "showOfferWall") {
      val placementName: String = call.argument<String>("name") ?: "";
      if (placementName.isEmpty()) {
        result.error("-1","参数错误","");
        return
      }
      IronSource.showOfferwall(placementName)
    } else if (call.method == "showVideo") {
      val placementName: String = call.argument<String>("name") ?: "";
      if (placementName.isEmpty()) {
        result.error("-1","参数错误","");
        return
      }
      IronSource.showRewardedVideo(placementName)
    } else if (call.method == "showInterstitial") {
      val placementName: String = call.argument<String>("name") ?: "";
      if (placementName.isEmpty()) {
        result.error("-1","参数错误","");
        return
      }
      IronSource.showInterstitial(placementName)
    } else if (call.method == "loadInterstitial") {
      IronSource.loadInterstitial()
    } else if (call.method == "loadRewardedVideo") {
      IronSource.loadRewardedVideo()
    } else if (call.method == "isInterstitialPlacementCapped") {
      val placementName: String = call.argument<String>("name") ?: "";
      if (placementName.isEmpty()) {
        result.error("-1","参数错误","");
        return
      }
      result.success(IronSource.isInterstitialPlacementCapped(placementName));
    } else if (call.method == "isRewardedVideoPlacementCapped") {
      val placementName: String = call.argument<String>("name") ?: "";
      if (placementName.isEmpty()) {
        result.error("-1","参数错误","");
        return
      }
      result.success(IronSource.isRewardedVideoPlacementCapped(placementName));
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivityForConfigChanges() {
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivity() {
  }
}

==> 0.0.3.tar.gz: android/src/main/kotlin/com/example/cs_ironsource_ad/CsIronsourceAdPlugin.kt <==
package com.example.cs_ironsource_ad

import android.app.Activity
import android.util.Log
import androidx.annotation.NonNull
import com.ironsource.mediationsdk.IronSource
import com.ironsource.mediationsdk.logger.IronSourceError
import com.ironsource.mediationsdk.model.Placement
import com.ironsource.mediationsdk.sdk.InterstitialListener
import com.ironsource.mediationsdk.sdk.OfferwallListener
import com.ironsource.mediationsdk.sdk.RewardedVideoListener

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result


/** CsIronsourceAdPlugin */
class CsIronsourceAdPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  var activity: Activity? = null

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "cs_ironsource_android")
    channel.setMethodCallHandler(this)
  }

  fun OnMethodCallHandler(method: String, args: Map<String, Any>?) {
    try {
      activity?.runOnUiThread(Runnable { channel.invokeMethod(method!!, args) })
    } catch (e: Exception) {
      Log.e("flutter_ironsource", "Error $e")
    }
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "init") {
      val appKey = call.argument<String>("appKey") ?: ""
      IronSource.init(activity, appKey, IronSource.AD_UNIT.OFFERWALL, IronSource.AD_UNIT.REWARDED_VIDEO, IronSource.AD_UNIT.INTERSTITIAL);
      IronSource.setOfferwallListener(object : OfferwallListener {
        //积分墙是否准备好
        override fun onOfferwallAvailable(isAvailable: Boolean) {
          OnMethodCallHandler("offerwallAvailable",  mapOf("isAvailable" to isAvailable))
        }

        //加载成功
        override fun onOfferwallOpened() {
          OnMethodCallHandler("offerwallOpened", null);
        }

        //积分墙展示错误
        override fun onOfferwallShowFailed(error: IronSourceError) {
          OnMethodCallHandler("offerwallShowFailed", mapOf("code" to error.getErrorCode(), "message" to error.getErrorMessage()))
        }

        //获取奖励
        override fun onOfferwallAdCredited(credits: Int, totalCredits: Int, totalCreditsFlag: Boolean): Boolean {
          OnMethodCallHandler("offerwallAdCredited", mapOf("credits" to credits, "totalCredits" to totalCredits, "totalCreditsFlag" to totalCreditsFlag))
          return true
        }

        //获取积分失败
        override fun onGetOfferwallCreditsFailed(error: IronSourceError) {
          OnMethodCallHandler("getOfferwallCreditsFailed", mapOf("code" to error.getErrorCode(), "message" to error.getErrorMessage()))
        }

        //关闭积分墙
        override fun onOfferwallClosed() {
          OnMethodCallHandler("offerwallClosed", null)
        }
      })

      // 激励视频
      IronSource.setRewardedVideoListener(object : RewardedVideoListener {
        override fun onRewardedVideoAdOpened(){
          OnMethodCallHandler("rewardedVideoAdOpened", null);
        }

        override fun onRewardedVideoAdClosed(){
          OnMethodCallHandler("rewardedVideoAdClosed", null)
        }

        override fun onRewardedVideoAvailabilityChanged(isAvailability: Boolean){
          OnMethodCallHandler("rewardedVideoAvailabilityChanged", mapOf("isAvailable" to isAvailability))
        }

        override fun onRewardedVideoAdStarted(){
          OnMethodCallHandler("rewardedVideoAdStarted", null)
        }

        override fun onRewardedVideoAdEnded(){
          OnMethodCallHandler("rewardedVideoAdEnded", null)
        }

        override fun onRewardedVideoAdRewarded(placement: Placement?){
          val rewardName = placement?.rewardName ?: "";
          val rewardAmount = placement?.rewardAmount ?: 0
          OnMethodCallHandler("rewardedVideoAdRewarded", mapOf<String, Any>("rewardName" to rewardName, "rewardAmount" to rewardAmount));
        }

        override fun onRewardedVideoAdShowFailed(error: IronSourceError?){
          val errorCode = error?.errorCode ?: -1;
          val errorMessage = error?.errorMessage ?: "mess is null";
          OnMethodCallHandler("rewardedVideoAdShowFailed", mapOf("code" to errorCode, "message" to errorMessage))
        }

        override fun onRewardedVideoAdClicked(placement: Placement?){
          val rewardName = placement?.rewardName ?: "";
          val rewardAmount = placement?.rewardAmount ?: 0
          OnMethodCallHandler("rewardedVideoAdClicked", mapOf("rewardName" to rewardName, "rewardAmount" to rewardAmount))
        }
      })

      // 插屏广告
      IronSource.setInterstitialListener(object :InterstitialListener {
        override fun onInterstitialAdReady(){
          OnMethodCallHandler("interstitialAdReady", null)
        }

        override fun onInterstitialAdLoadFailed(error: IronSourceError?){
          val errorCode = error?.errorCode ?: -1;
          val errorMessage = error?.errorMessage ?: "mess is null";
          OnMethodCallHandler("interstitialAdLoadFailed", mapOf("code" to errorCode, "message" to errorMessage))
        }

        override fun onInterstitialAdOpened(){
          OnMethodCallHandler("interstitialAdOpened", null)
        }

        override fun onInterstitialAdClosed(){
          OnMethodCallHandler("interstitialAdClosed", null)
        }

        override fun onInterstitialAdShowSucceeded(){
          OnMethodCallHandler("interstitialAdShowSucceeded", null)
        }

        override fun onInterstitialAdShowFailed(error: IronSourceError?){
          val errorCode = error?.errorCode ?: -1;
          val errorMessage = error?.errorMessage ?: "mess is null";
          OnMethodCallHandler("interstitialAdShowFailed", mapOf("code" to errorCode, "message" to errorMessage));
        }

        override fun onInterstitialAdClicked(){
          OnMethodCallHandler("interstitialAdClicked", null);
        }
      })
    }  else if (call.method == "setUserId") {
      val userId: String = call.argument<String>("userId") ?: return;
      IronSource.setUserId(userId)
    } else if (call.method == "getOfferwallCredits") {
      IronSource.getOfferwallCredits()
    } else if (call.method == "showOfferWall") {
      val placementName: String = call.argument<String>("name") ?: "";
      if (placementName.isEmpty()) {
        result.error("-1","参数错误","");
        return
      }
      IronSource.showOfferwall(placementName)
    } else if (call.method == "showRewardedVideo") {
      val placementName: String = call.argument<String>("name") ?: "";
      if (placementName.isEmpty()) {
        result.error("-1","参数错误","");
        return
      }
      IronSource.showRewardedVideo(placementName)
    } else if (call.method == "showInterstitial") {
      val placementName: String = call.argument<String>("name") ?: "";
      if (placementName.isEmpty()) {
        result.error("-1","参数错误","");
        return
      }
      IronSource.showInterstitial(placementName)
    } else if (call.method == "loadInterstitial") {
      IronSource.loadInterstitial()
    } else if (call.method == "loadRewardedVideo") {
      IronSource.loadRewardedVideo()
    } else if (call.method == "isOfferwallAvailable") {
      result.success(IronSource.isOfferwallAvailable())
    } else if (call.method == "isRewardedVideoAvailable") {
      result.success(IronSource.isRewardedVideoAvailable())
    } else if (call.method == "isInterstitialReady") {
      result.success(IronSource.isInterstitialReady());
    } else if (call.method == "isInterstitialPlacementCapped") {
      val placementName: String = call.argument<String>("name") ?: "";
      if (placementName.isEmpty()) {
        result.error("-1","参数错误","");
        return
      }
      result.success(IronSource.isInterstitialPlacementCapped(placementName));
    } else if (call.method == "isRewardedVideoPlacementCapped") {
      val placementName: String = call.argument<String>("name") ?: "";
      if (placementName.isEmpty()) {
        result.error("-1","参数错误","");
        return
      }
      result.success(IronSource.isRewardedVideoPlacementCapped(placementName));
    } else if (call.method == "onResume") {
      IronSource.onResume(activity);
    } else if (call.method == "onPause") {
      IronSource.onPause(activity);
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivityForConfigChanges() {
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivity() {
  }
}
